import Vue from 'vue';

import FormCadastro from './components/FormCadastro';

Vue.component('form-cadastro', FormCadastro);

new Vue({
    el: '#app'
});

jQuery(window).on('scroll', function(){ 
    if(this.scrollY == 0) {
        jQuery('.main-header--center').removeClass('small') 
    } else{
        jQuery('.main-header--center').addClass('small') 
    }
});

if(jQuery('.section-youtube').length > 0 ){
    setTimeout(function(){
        jQuery('.section-youtube .overflow-auto').css('max-height', jQuery('.js-youtube-channel--iframe').height()+'px'); 
    }, 500);
}

if(jQuery('#mapa-cadastro').length > 0 ){
    var mymap = L.map('mapa-cadastro').setView([-16, -57], 4);
    L.tileLayer('https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ3N3gifQ.rJcFIG214AriISLbB6B5aw', {
		maxZoom: 18,
		attribution: 'Map data &copy; <a href="https://www.openstreetmap.org/">OpenStreetMap</a> contributors, ' +
			'<a href="https://creativecommons.org/licenses/by-sa/2.0/">CC-BY-SA</a>, ' +
			'Imagery © <a href="https://www.mapbox.com/">Mapbox</a>',
		id: 'mapbox.streets'
    }).addTo(mymap);
    
    var flagIcon = L.icon({
        iconUrl: '/wp-content/themes/comite-nacional-lula-livre/assets/images/map-icon.png',
        shadowUrl: '',
        iconSize:     [30, 30], // size of the icon
        shadowSize:   [0, 0], // size of the shadow
        iconAnchor:   [15, 15], // point of the icon which will correspond to marker's location
        shadowAnchor: [0, 0],  // the same for the shadow
        popupAnchor:  [0, 0] // point from which the popup should open relative to the iconAnchor
    });

    if(window.mapa_cadastro){
        window.mapa_cadastro.map(m => {
            let marker = L.marker([m.latitude, m.longitude], {icon: flagIcon}).addTo(mymap);
            marker.bindPopup(`
                <b>Endereço: </b> ${m.endereco.substring(0, 38)}... <br>
                <b>Cidade: </b> ${m.cidade} <br>
                <b>Contato: </b> <a href="mailto:${m.email}">${m.email}</a>
            `)
        })
    }
}

window.fetchArt = function (id){
    jQuery.get('/art/'+id, {}, function(response){
        const modal = jQuery('.modal-art--content').html(response);
        const modalImages = modal[0].querySelectorAll('img');

        modalImages.forEach(image => {
            const downloadLink = document.createElement('a');
            downloadLink.setAttribute('href', image.getAttribute('src'));
            downloadLink.setAttribute('download', 'download');
            downloadLink.classList.add('dowload-image-link');
            downloadLink.innerHTML = '<svg aria-hidden="true" focusable="false" data-icon="" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512" class="" style="color: white;font-size: 28px;width: 16px;"><path fill="currentColor" d="M224 136V0H24C10.7 0 0 10.7 0 24v464c0 13.3 10.7 24 24 24h336c13.3 0 24-10.7 24-24V160H248c-13.2 0-24-10.8-24-24zm76.45 211.36l-96.42 95.7c-6.65 6.61-17.39 6.61-24.04 0l-96.42-95.7C73.42 337.29 80.54 320 94.82 320H160v-80c0-8.84 7.16-16 16-16h32c8.84 0 16 7.16 16 16v80h65.18c14.28 0 21.4 17.29 11.27 27.36zM377 105L279.1 7c-4.5-4.5-10.6-7-17-7H256v128h128v-6.1c0-6.3-2.5-12.4-7-16.9z" class=""></path></svg>';

            image.parentElement.style.position = 'relative';

            jQuery(downloadLink).insertAfter(image);
            jQuery(image.parentElement).addClass('image-download-button');

        })
        
        jQuery('#modal-art,#modal-art-wrapper').css({ 'display' : 'block', 'backface-visiblity' : 'initial' });
    });
}

jQuery(document).ready(function(){
    if ("geolocation" in navigator) {
        /* geolocation is available */
      } 

    $('.art-card a').click(function(e){
        e.preventDefault();
        fetchArt(jQuery(this).data('art-id'));
    });


    $('#modal-art .close-button').click(function(e){
        jQuery('#modal-art,#modal-art-wrapper').css({ 'display' : 'none' });
    });
        

    $('.featured-card .play-button').click(function(){
        let $parent = $(this).parents('.featured-card');
        let $iframe = $parent.find('iframe');

        $parent.addClass('play');
        $iframe.attr('src', $iframe.attr('src') + '&autoplay=1');
    })
});

window.downloadFile = function (sUrl) {

    //iOS devices do not support downloading. We have to inform user about this.
    if (/(iP)/g.test(navigator.userAgent)) {
        //alert('Your device does not support files downloading. Please try again in desktop browser.');
        window.open(sUrl, '_blank');
        return false;
    }

    //If in Chrome or Safari - download via virtual link click
    if (window.downloadFile.isChrome || window.downloadFile.isSafari) {
        //Creating new link node.
        var link = document.createElement('a');
        link.href = sUrl;
        link.setAttribute('target','_blank');

        if (link.download !== undefined) {
            //Set HTML5 download attribute. This will prevent file from opening if supported.
            var fileName = sUrl.substring(sUrl.lastIndexOf('/') + 1, sUrl.length);
            link.download = fileName;
        }

        //Dispatching click event.
        if (document.createEvent) {
            var e = document.createEvent('MouseEvents');
            e.initEvent('click', true, true);
            link.dispatchEvent(e);
            return true;
        }
    }

    // Force file download (whether supported by server).
    if (sUrl.indexOf('?') === -1) {
        sUrl += '?download';
    }

    window.open(sUrl, '_blank');
    return true;
}

window.downloadFile.isChrome = navigator.userAgent.toLowerCase().indexOf('chrome') > -1;
window.downloadFile.isSafari = navigator.userAgent.toLowerCase().indexOf('safari') > -1;