<?php

/*
  Widget Name: Cards - Posts mais lidos
  Description: Adiciona um card de post
  Author: hacklab/
  Author URI: https://hacklab.com.br/
 */

namespace widgets;

class CardsMaisLidos extends \SiteOrigin_Widget {

    function __construct() {
        $fields = [
            'tipo' => [
                'type' => 'select',
                'label' => 'Tipo de Card',
                'default' => '',
                'options' => array(
                    'card-xsmall' => 'Imagem pequena',
                    'card-small' => 'Imagem média',
                    'card-medium' => 'Imagem grande',
                )
            ],
            'link_externo' => [
                'type' => 'checkbox',
                'label' => 'Link externo',
                'description' => 'O link deve abrir numa nova aba',
                'default' => FALSE,
            ],
            'hide_linha_fina' => [
                'type' => 'checkbox',
                'label' => 'Não exibir a linha fina',
                'default' => FALSE,
            ],
            'show_excerpt' => [
                'type' => 'checkbox',
                'label' => 'Exibir o resumo do post',
                'default' => FALSE,
            ],
            'num_days' => [
                'type' => 'number',
                'label' => 'Número de dias',
                'description' => 'número de dias que deve contar para a gerar a lista dos mais lidos (14 por padrão)',
                'default' => 14
            ],
            'num_posts' => [
                'type' => 'number',
                'label' => 'Número de posts',
                'description' => 'número de posts que devem ser listados (4 por padrão)',
                'default' => 4
            ],
        ];

        parent::__construct('cards-mais-lidos', "Cards de posts mais lidos", [
            'panels_groups' => [WIDGETGROUP_MAIN, WIDGETGROUP_CARDS],
            'description' => 'Adiciona uma lista de cards dos mais lidos'
                ], [], $fields, plugin_dir_path(__FILE__)
        );
    }

    function get_template_name($instance) {
        return 'template';
    }

    function get_style_name($instance) {
        return 'style';
    }

    function get_template_variables($instance, $args) {

        if(false){
            $wpdb = new \wpdb;
        }


        $from = date('Y-m-d', strtotime('- ' . $instance['num_days'] . ' days'));

        $pageviews_data = \AjaxPageviews::get_top_viewed($instance['num_posts'], [
            'post_type' => 'post',
            'from' => $from
        ]);

        $ids = array_map(function($el){ return $el->post_id; }, $pageviews_data);
        if(!$ids){
            $ids = [-1];
        }
        $query_args = [
            'post_type' => 'post',
            'post__in' => $ids,
            'orderby' => 'post__in',
            'nopaging' => true
        ];
        
        return ['query_args' => $query_args, 'pageviews_data' => $pageviews_data];
    }

}

Siteorigin_widget_register('cards-mais-lidos', __FILE__, 'widgets\CardsMaisLidos');
